@@ -1,10 +1,10 @@
 /*
- * Nautilus Actions
+ * Nautilus-Actions
  * A Nautilus extension which offers configurable context menu actions.
  *
  * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006, 2007, 2008 Frederic Ruaudel and others (see AUTHORS)
- * Copyright (C) 2009, 2010 Pierre Wieser and others (see AUTHORS)
+ * Copyright (C) 2009, 2010, 2011 Pierre Wieser and others (see AUTHORS)
  *
  * This Program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -105,6 +105,7 @@ nadp_iio_provider_read_items( const NAIIOProvider *provider, GSList **messages )
 
 		if( item ){
 			items = g_list_prepend( items, item );
+			na_object_dump( item );
 		}
 	}
 
@@ -375,9 +376,15 @@ nadp_reader_iimporter_import_from_uri( const NAIImporter *instance, NAIImporterI
 				ndf, &parms->messages );
 
 		if( parms->imported ){
-			code = IMPORTER_CODE_OK;
 			g_return_val_if_fail( NA_IS_OBJECT_ITEM( parms->imported ), IMPORTER_CODE_NOT_WILLING_TO );
 
+			/* remove the weak reference on desktop file set by 'item_from_desktop_file'
+			 * as we must consider this #NAObjectItem as a new one
+			 */
+			na_object_set_provider_data( parms->imported, NULL );
+			g_object_weak_unref( G_OBJECT( parms->imported ), ( GWeakNotify ) desktop_weak_notify, ndf );
+			g_object_unref( ndf );
+
 			manage_parms.version = 1;
 			manage_parms.imported = parms->imported;
 			manage_parms.check_fn = parms->check_fn;
@@ -395,6 +402,7 @@ nadp_reader_iimporter_import_from_uri( const NAIImporter *instance, NAIImporterI
 
 		if( code != IMPORTER_CODE_OK ){
 			if( parms->imported ){
+				g_debug( "%s: unreffing imported item %p as na_iimporter_manage_import_mode didn't return IMPORTER_CODE_OK", thisfn, parms->imported );
 				g_object_unref( parms->imported );
 				parms->imported = NULL;
 			}
@@ -476,7 +484,7 @@ read_start_profile_attach_profile( const NAIFactoryProvider *provider, NAObjectP
 NADataBoxed *
 nadp_reader_ifactory_provider_read_data( const NAIFactoryProvider *reader, void *reader_data, const NAIFactoryObject *object, const NADataDef *def, GSList **messages )
 {
-	static const gchar *thisfn = "nadp_reader_ifactory_provider_read_value";
+	static const gchar *thisfn = "nadp_reader_ifactory_provider_read_data";
 	NADataBoxed *boxed;
 	gboolean found;
 	NadpReaderData *nrd;
@@ -487,13 +495,6 @@ nadp_reader_ifactory_provider_read_data( const NAIFactoryProvider *reader, void
 	GSList *slist_value;
 	guint uint_value;
 
-	/*g_debug( "%s: reader=%p (%s), reader_data=%p, def=%p (%s), messages=%p",
-			thisfn,
-			( void * ) reader, G_OBJECT_TYPE_NAME( reader ),
-			( void * ) reader_data,
-			( void * ) def, def->name,
-			( void * ) messages );*/
-
 	g_return_val_if_fail( NA_IS_IFACTORY_PROVIDER( reader ), NULL );
 	g_return_val_if_fail( NADP_IS_DESKTOP_PROVIDER( reader ), NULL );
 	g_return_val_if_fail( NA_IS_IFACTORY_OBJECT( object ), NULL );
@@ -519,47 +520,46 @@ nadp_reader_ifactory_provider_read_data( const NAIFactoryProvider *reader, void
 
 			switch( def->type ){
 
-				case NAFD_TYPE_LOCALE_STRING:
+				case NA_DATA_TYPE_LOCALE_STRING:
 					str_value = nadp_desktop_file_get_locale_string( nrd->ndf, group, def->desktop_entry, &found, def->default_value );
 					if( found ){
 						boxed = na_data_boxed_new( def );
-						na_data_boxed_set_from_void( boxed, str_value );
+						na_boxed_set_from_void( NA_BOXED( boxed ), str_value );
 					}
 					g_free( str_value );
 					break;
 
-				case NAFD_TYPE_STRING:
+				case NA_DATA_TYPE_STRING:
 					str_value = nadp_desktop_file_get_string( nrd->ndf, group, def->desktop_entry, &found, def->default_value );
 					if( found ){
 						boxed = na_data_boxed_new( def );
-						na_data_boxed_set_from_void( boxed, str_value );
+						na_boxed_set_from_void( NA_BOXED( boxed ), str_value );
 					}
 					g_free( str_value );
 					break;
 
-				case NAFD_TYPE_BOOLEAN:
+				case NA_DATA_TYPE_BOOLEAN:
 					bool_value = nadp_desktop_file_get_boolean( nrd->ndf, group, def->desktop_entry, &found, na_core_utils_boolean_from_string( def->default_value ));
-					g_debug( "%s: name=%s, found=%s, value=%s", thisfn, def->name, found ? "True":"False", bool_value ? "True":"False" );
 					if( found ){
 						boxed = na_data_boxed_new( def );
-						na_data_boxed_set_from_void( boxed, GUINT_TO_POINTER( bool_value ));
+						na_boxed_set_from_void( NA_BOXED( boxed ), GUINT_TO_POINTER( bool_value ));
 					}
 					break;
 
-				case NAFD_TYPE_STRING_LIST:
+				case NA_DATA_TYPE_STRING_LIST:
 					slist_value = nadp_desktop_file_get_string_list( nrd->ndf, group, def->desktop_entry, &found, def->default_value );
 					if( found ){
 						boxed = na_data_boxed_new( def );
-						na_data_boxed_set_from_void( boxed, slist_value );
+						na_boxed_set_from_void( NA_BOXED( boxed ), slist_value );
 					}
 					na_core_utils_slist_free( slist_value );
 					break;
 
-				case NAFD_TYPE_UINT:
+				case NA_DATA_TYPE_UINT:
 					uint_value = nadp_desktop_file_get_uint( nrd->ndf, group, def->desktop_entry, &found, atoi( def->default_value ));
 					if( found ){
 						boxed = na_data_boxed_new( def );
-						na_data_boxed_set_from_void( boxed, GUINT_TO_POINTER( uint_value ));
+						na_boxed_set_from_void( NA_BOXED( boxed ), GUINT_TO_POINTER( uint_value ));
 					}
 					break;
 
@@ -577,7 +577,7 @@ nadp_reader_ifactory_provider_read_data( const NAIFactoryProvider *reader, void
 }
 
 /*
- * called when each NAIFactoryObject object has been readen
+ * called when each NAIFactoryObject object has been read
  */
 void
 nadp_reader_ifactory_provider_read_done( const NAIFactoryProvider *reader, void *reader_data, const NAIFactoryObject *serializable, GSList **messages )
