@@ -40,33 +40,20 @@
 
 #include <core/na-io-provider.h>
 
-#include "base-iprefs.h"
 #include "base-window.h"
 #include "nact-application.h"
-#include "nact-iprefs.h"
 #include "nact-main-statusbar.h"
-#include "nact-gtk-utils.h"
-#include "nact-iactions-list.h"
+#include "base-gtk-utils.h"
 #include "nact-main-tab.h"
 #include "nact-iaction-tab.h"
+#include "nact-icon-chooser.h"
 
 /* private interface data
  */
-struct NactIActionTabInterfacePrivate {
+struct _NactIActionTabInterfacePrivate {
 	void *empty;						/* so that gcc -pedantic is happy */
 };
 
-/* columns in the icon combobox
- */
-enum {
-	ICON_STOCK_COLUMN = 0,
-	ICON_LABEL_COLUMN,
-	ICON_N_COLUMN
-};
-
-#define IPREFS_ICONS_DIALOG					"icons-chooser"
-#define IPREFS_ICONS_PATH					"icons-path"
-
 /* IActionTab properties, set against the GObject instance
  */
 #define IACTION_TAB_PROP_STATUS_CONTEXT		"nact-iaction-tab-status-context"
@@ -79,8 +66,8 @@ static GType         register_type( void );
 static void          interface_base_init( NactIActionTabInterface *klass );
 static void          interface_base_finalize( NactIActionTabInterface *klass );
 
-static void          on_iactions_list_column_edited( NactIActionTab *instance, NAObject *object, gchar *text, gint column );
-static void          on_tab_updatable_selection_changed( NactIActionTab *instance, gint count_selected );
+static void          on_tree_view_content_changed( NactIActionTab *instance, NAObject *object, gpointer user_data );
+static void          on_main_selection_changed( NactIActionTab *instance, GList *selected_items, gpointer user_data );
 
 static void          on_target_selection_toggled( GtkToggleButton *button, NactIActionTab *instance );
 static void          on_target_location_toggled( GtkToggleButton *button, NactIActionTab *instance );
@@ -94,15 +81,8 @@ static void          setup_toolbar_label( NactIActionTab *instance, NAObjectItem
 static void          on_toolbar_label_changed( GtkEntry *entry, NactIActionTab *instance );
 static void          toolbar_label_set_sensitive( NactIActionTab *instance, NAObjectItem *item );
 static void          on_tooltip_changed( GtkEntry *entry, NactIActionTab *instance );
-static GtkTreeModel *create_stock_icon_model( void );
-static void          icon_combo_list_set_layout( GtkComboBox* combo );
 static void          on_icon_browse( GtkButton *button, NactIActionTab *instance );
 static void          on_icon_changed( GtkEntry *entry, NactIActionTab *instance );
-static void          icon_preview_cb( GtkFileChooser *dialog, GtkWidget *preview );
-static gint          sort_stock_ids_by_label( gconstpointer a, gconstpointer b );
-static gchar        *strip_underscore( const gchar *text );
-static void          release_icon_combobox( NactIActionTab *instance );
-static GtkWidget    *get_icon_combo_box( NactIActionTab *instance );
 
 GType
 nact_iaction_tab_get_type( void )
@@ -184,6 +164,8 @@ interface_base_finalize( NactIActionTabInterface *klass )
  * icon is rendered for GTK_ICON_SIZE_MENU (na_object_item_get_pixbuf)
  *
  * Starting with 3.0.3, the ComboBox is dynamically created into its container.
+ * Starting with 3.1.0, the ComboBox is replaced with a GtkEntry (thanks to new
+ * Icon Chooser).
  */
 void
 nact_iaction_tab_initial_load_toplevel( NactIActionTab *instance )
@@ -201,9 +183,6 @@ nact_iaction_tab_initial_load_toplevel( NactIActionTab *instance )
 #else
 	GtkRequisition requisition;
 #endif
-	GtkWidget *container;
-	GtkWidget *icon_combo;
-	GtkTreeModel *model;
 
 	g_return_if_fail( NACT_IS_IACTION_TAB( instance ));
 
@@ -222,24 +201,6 @@ nact_iaction_tab_initial_load_toplevel( NactIActionTab *instance )
 #endif
 		gtk_widget_set_size_request( GTK_WIDGET( frame ), size, size );
 		gtk_frame_set_shadow_type( frame, GTK_SHADOW_IN );
-
-		model = create_stock_icon_model();
-
-/* GtkComboBoxEntry is deprecated from Gtk+3
- * see. http://git.gnome.org/browse/gtk+/commit/?id=9612c648176378bf237ad0e1a8c6c995b0ca7c61
- * while 'has_entry' property exists since 2.24
- */
-#if GTK_CHECK_VERSION( 2, 24, 0 )
-		icon_combo = gtk_combo_box_new_with_model_and_entry( model );
-		gtk_combo_box_set_entry_text_column( GTK_COMBO_BOX( icon_combo ), ICON_STOCK_COLUMN );
-#else
-		icon_combo = gtk_combo_box_entry_new_with_model( model, ICON_STOCK_COLUMN );
-#endif
-
-		icon_combo_list_set_layout( GTK_COMBO_BOX( icon_combo ));
-		g_object_unref( model );
-		container = base_window_get_widget( BASE_WINDOW( instance ), "ActionIconHBox" );
-		gtk_box_pack_start( GTK_BOX( container ), icon_combo, TRUE, TRUE, 0 );
 	}
 }
 
@@ -247,7 +208,7 @@ void
 nact_iaction_tab_runtime_init_toplevel( NactIActionTab *instance )
 {
 	static const gchar *thisfn = "nact_iaction_tab_runtime_init_toplevel";
-	GtkWidget *label_widget, *tooltip_widget, *icon_widget;
+	GtkWidget *label_widget, *tooltip_widget, *icon_entry;
 	GtkWidget *button;
 
 	g_return_if_fail( NACT_IS_IACTION_TAB( instance ));
@@ -256,17 +217,11 @@ nact_iaction_tab_runtime_init_toplevel( NactIActionTab *instance )
 
 		g_debug( "%s: instance=%p", thisfn, ( void * ) instance );
 
-		base_window_signal_connect(
-				BASE_WINDOW( instance ),
-				G_OBJECT( instance ),
-				MAIN_WINDOW_SIGNAL_SELECTION_CHANGED,
-				G_CALLBACK( on_tab_updatable_selection_changed ));
+		base_window_signal_connect( BASE_WINDOW( instance ),
+				G_OBJECT( instance ), MAIN_SIGNAL_SELECTION_CHANGED, G_CALLBACK( on_main_selection_changed ));
 
-		base_window_signal_connect(
-				BASE_WINDOW( instance ),
-				G_OBJECT( instance ),
-				IACTIONS_LIST_SIGNAL_COLUMN_EDITED,
-				G_CALLBACK( on_iactions_list_column_edited ));
+		base_window_signal_connect( BASE_WINDOW( instance ),
+				G_OBJECT( instance ), MAIN_SIGNAL_ITEM_UPDATED, G_CALLBACK( on_tree_view_content_changed ));
 
 		button = base_window_get_widget( BASE_WINDOW( instance ), "ActionTargetSelectionButton" );
 		base_window_signal_connect(
@@ -317,10 +272,10 @@ nact_iaction_tab_runtime_init_toplevel( NactIActionTab *instance )
 				"changed",
 				G_CALLBACK( on_tooltip_changed ));
 
-		icon_widget = get_icon_combo_box( instance );
+		icon_entry = base_window_get_widget( BASE_WINDOW( instance ), "ActionIconEntry" );
 		base_window_signal_connect(
 				BASE_WINDOW( instance ),
-				G_OBJECT( gtk_bin_get_child( GTK_BIN( icon_widget ))),
+				G_OBJECT( icon_entry ),
 				"changed",
 				G_CALLBACK( on_icon_changed ));
 
@@ -356,8 +311,6 @@ nact_iaction_tab_dispose( NactIActionTab *instance )
 	if( st_initialized && !st_finalized ){
 
 		g_debug( "%s: instance=%p", thisfn, ( void * ) instance );
-
-		release_icon_combobox( instance );
 	}
 }
 
@@ -389,9 +342,10 @@ nact_iaction_tab_has_label( NactIActionTab *instance )
 }
 
 static void
-on_iactions_list_column_edited( NactIActionTab *instance, NAObject *object, gchar *text, gint column )
+on_tree_view_content_changed( NactIActionTab *instance, NAObject *object, gpointer user_data )
 {
 	GtkWidget *label_widget;
+	gchar *label;
 
 	g_return_if_fail( NACT_IS_IACTION_TAB( instance ));
 
@@ -399,15 +353,18 @@ on_iactions_list_column_edited( NactIActionTab *instance, NAObject *object, gcha
 
 		if( object && NA_IS_OBJECT_ITEM( object )){
 			label_widget = base_window_get_widget( BASE_WINDOW( instance ), "ActionMenuLabelEntry" );
-			gtk_entry_set_text( GTK_ENTRY( label_widget ), text );
+			label = na_object_get_label( object );
+			gtk_entry_set_text( GTK_ENTRY( label_widget ), label );
+			g_free( label );
 		}
 	}
 }
 
 static void
-on_tab_updatable_selection_changed( NactIActionTab *instance, gint count_selected )
+on_main_selection_changed( NactIActionTab *instance, GList *selected_items, gpointer user_data )
 {
-	static const gchar *thisfn = "nact_iaction_tab_on_tab_updatable_selection_changed";
+	static const gchar *thisfn = "nact_iaction_tab_on_main_selection_changed";
+	guint count_selected;
 	gboolean enable_tab;
 	NAObjectItem *item;
 	gboolean editable;
@@ -424,7 +381,9 @@ on_tab_updatable_selection_changed( NactIActionTab *instance, gint count_selecte
 
 	if( st_initialized && !st_finalized ){
 
-		g_debug( "%s: instance=%p, count_selected=%d", thisfn, ( void * ) instance, count_selected );
+		count_selected = g_list_length( selected_items );
+		g_debug( "%s: instance=%p, selected_items=%p (count=%u)",
+				thisfn, ( void * ) instance, ( void * ) selected_items, count_selected );
 
 		enable_tab = ( count_selected == 1 );
 		nact_main_tab_enable_page( NACT_MAIN_WINDOW( instance ), TAB_ACTION, enable_tab );
@@ -433,8 +392,8 @@ on_tab_updatable_selection_changed( NactIActionTab *instance, gint count_selecte
 
 		g_object_get(
 			G_OBJECT( instance ),
-			TAB_UPDATABLE_PROP_SELECTED_ITEM, &item,
-			TAB_UPDATABLE_PROP_EDITABLE, &editable,
+			MAIN_PROP_ITEM, &item,
+			MAIN_PROP_EDITABLE, &editable,
 			NULL );
 
 		target_selection =
@@ -458,12 +417,12 @@ on_tab_updatable_selection_changed( NactIActionTab *instance, gint count_selecte
 		toggle = GTK_TOGGLE_BUTTON( base_window_get_widget( BASE_WINDOW( instance ), "ActionTargetSelectionButton" ));
 		gtk_toggle_button_set_active( toggle, target_selection || ( item && NA_IS_OBJECT_MENU( item )));
 		gtk_widget_set_sensitive( GTK_WIDGET( toggle ), item && NA_IS_OBJECT_ACTION( item ));
-		nact_gtk_utils_set_editable( G_OBJECT( toggle ), editable );
+		base_gtk_utils_set_editable( G_OBJECT( toggle ), editable );
 
 		toggle = GTK_TOGGLE_BUTTON( base_window_get_widget( BASE_WINDOW( instance ), "ActionTargetLocationButton" ));
 		gtk_toggle_button_set_active( toggle, target_location || ( item && NA_IS_OBJECT_MENU( item )));
 		gtk_widget_set_sensitive( GTK_WIDGET( toggle ), item && NA_IS_OBJECT_ACTION( item ));
-		nact_gtk_utils_set_editable( G_OBJECT( toggle ), editable );
+		base_gtk_utils_set_editable( G_OBJECT( toggle ), editable );
 
 		enable_label = target_selection || target_location || ( item && NA_IS_OBJECT_MENU( item ));
 		label_widget = base_window_get_widget( BASE_WINDOW( instance ), "ActionMenuLabelEntry" );
@@ -475,25 +434,25 @@ on_tab_updatable_selection_changed( NactIActionTab *instance, gint count_selecte
 		}
 		g_free( label );
 		gtk_widget_set_sensitive( label_widget, enable_label );
-		nact_gtk_utils_set_editable( G_OBJECT( label_widget ), editable );
+		base_gtk_utils_set_editable( G_OBJECT( label_widget ), editable );
 
 		toggle = GTK_TOGGLE_BUTTON( base_window_get_widget( BASE_WINDOW( instance ), "ActionTargetToolbarButton" ));
 		gtk_toggle_button_set_active( toggle, target_toolbar );
 		gtk_widget_set_sensitive( GTK_WIDGET( toggle ), item && NA_IS_OBJECT_ACTION( item ));
-		nact_gtk_utils_set_editable( G_OBJECT( toggle ), editable );
+		base_gtk_utils_set_editable( G_OBJECT( toggle ), editable );
 
 		toggle = GTK_TOGGLE_BUTTON( base_window_get_widget( BASE_WINDOW( instance ), "ToolbarSameLabelButton" ));
 		same_label = item && NA_IS_OBJECT_ACTION( item ) ? na_object_is_toolbar_same_label( item ) : FALSE;
 		gtk_toggle_button_set_active( toggle, same_label );
 		gtk_widget_set_sensitive( GTK_WIDGET( toggle ), target_toolbar );
-		nact_gtk_utils_set_editable( G_OBJECT( toggle ), editable );
+		base_gtk_utils_set_editable( G_OBJECT( toggle ), editable );
 
 		label_widget = base_window_get_widget( BASE_WINDOW( instance ), "ActionToolbarLabelEntry" );
 		label = item && NA_IS_OBJECT_ACTION( item ) ? na_object_get_toolbar_label( item ) : g_strdup( "" );
 		gtk_entry_set_text( GTK_ENTRY( label_widget ), label );
 		g_free( label );
 		gtk_widget_set_sensitive( label_widget, target_toolbar && !same_label );
-		nact_gtk_utils_set_editable( G_OBJECT( label_widget ), editable );
+		base_gtk_utils_set_editable( G_OBJECT( label_widget ), editable );
 
 		label_widget = base_window_get_widget( BASE_WINDOW( instance ), "ActionToolbarLabelLabel" );
 		gtk_widget_set_sensitive( label_widget, target_toolbar && !same_label );
@@ -503,17 +462,17 @@ on_tab_updatable_selection_changed( NactIActionTab *instance, gint count_selecte
 		tooltip = tooltip ? tooltip : g_strdup( "" );
 		gtk_entry_set_text( GTK_ENTRY( tooltip_widget ), tooltip );
 		g_free( tooltip );
-		nact_gtk_utils_set_editable( G_OBJECT( tooltip_widget ), editable );
+		base_gtk_utils_set_editable( G_OBJECT( tooltip_widget ), editable );
 
-		icon_widget = get_icon_combo_box( instance );
+		icon_widget = base_window_get_widget( BASE_WINDOW( instance ), "ActionIconEntry" );
 		icon = item ? na_object_get_icon( item ) : g_strdup( "" );
 		icon = icon ? icon : g_strdup( "" );
-		gtk_entry_set_text( GTK_ENTRY( gtk_bin_get_child( GTK_BIN( icon_widget ))), icon );
+		gtk_entry_set_text( GTK_ENTRY( icon_widget ), icon );
 		g_free( icon );
-		nact_gtk_utils_set_editable( G_OBJECT( icon_widget ), editable );
+		base_gtk_utils_set_editable( G_OBJECT( icon_widget ), editable );
 
 		icon_button = GTK_BUTTON( base_window_get_widget( BASE_WINDOW( instance ), "ActionIconBrowseButton" ));
-		nact_gtk_utils_set_editable( G_OBJECT( icon_button ), editable );
+		base_gtk_utils_set_editable( G_OBJECT( icon_button ), editable );
 
 		st_on_selection_change = FALSE;
 	}
@@ -528,13 +487,12 @@ on_target_selection_toggled( GtkToggleButton *button, NactIActionTab *instance )
 	gboolean editable;
 
 	if( !st_on_selection_change ){
-
 		g_debug( "%s: button=%p, instance=%p", thisfn, ( void * ) button, ( void * ) instance );
 
 		g_object_get(
 			G_OBJECT( instance ),
-			TAB_UPDATABLE_PROP_SELECTED_ITEM, &item,
-			TAB_UPDATABLE_PROP_EDITABLE, &editable,
+			MAIN_PROP_ITEM, &item,
+			MAIN_PROP_EDITABLE, &editable,
 			NULL );
 
 		g_debug( "%s: item=%p (%s), editable=%s",
@@ -546,7 +504,7 @@ on_target_selection_toggled( GtkToggleButton *button, NactIActionTab *instance )
 
 			if( editable ){
 				na_object_set_target_selection( item, is_target );
-				g_signal_emit_by_name( G_OBJECT( instance ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, item, FALSE );
+				g_signal_emit_by_name( G_OBJECT( instance ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, item, 0 );
 
 			} else {
 				g_signal_handlers_block_by_func(( gpointer ) button, on_target_selection_toggled, instance );
@@ -566,13 +524,12 @@ on_target_location_toggled( GtkToggleButton *button, NactIActionTab *instance )
 	gboolean editable;
 
 	if( !st_on_selection_change ){
-
 		g_debug( "%s: button=%p, instance=%p", thisfn, ( void * ) button, ( void * ) instance );
 
 		g_object_get(
 			G_OBJECT( instance ),
-			TAB_UPDATABLE_PROP_SELECTED_ITEM, &item,
-			TAB_UPDATABLE_PROP_EDITABLE, &editable,
+			MAIN_PROP_ITEM, &item,
+			MAIN_PROP_EDITABLE, &editable,
 			NULL );
 
 		g_debug( "%s: item=%p (%s), editable=%s",
@@ -584,7 +541,7 @@ on_target_location_toggled( GtkToggleButton *button, NactIActionTab *instance )
 
 			if( editable ){
 				na_object_set_target_location( item, is_target );
-				g_signal_emit_by_name( G_OBJECT( instance ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, item, FALSE );
+				g_signal_emit_by_name( G_OBJECT( instance ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, item, 0 );
 
 			} else {
 				g_signal_handlers_block_by_func(( gpointer ) button, on_target_location_toggled, instance );
@@ -613,7 +570,7 @@ check_for_label( NactIActionTab *instance, GtkEntry *entry, const gchar *label )
 
 		g_object_get(
 				G_OBJECT( instance ),
-				TAB_UPDATABLE_PROP_SELECTED_ITEM, &item,
+				MAIN_PROP_ITEM, &item,
 				NULL );
 
 		if( item && g_utf8_strlen( label, -1 ) == 0 ){
@@ -632,24 +589,29 @@ check_for_label( NactIActionTab *instance, GtkEntry *entry, const gchar *label )
 static void
 on_label_changed( GtkEntry *entry, NactIActionTab *instance )
 {
+	static const gchar *thisfn = "nact_iaction_tab_on_label_changed";
 	NAObjectItem *item;
 	const gchar *label;
 
-	g_object_get(
-			G_OBJECT( instance ),
-			TAB_UPDATABLE_PROP_SELECTED_ITEM, &item,
-			NULL );
+	if( !st_on_selection_change ){
+		g_debug( "%s: entry=%p, instance=%p", thisfn, ( void * ) entry, ( void * ) instance );
 
-	if( item ){
-		label = gtk_entry_get_text( entry );
-		na_object_set_label( item, label );
-		check_for_label( instance, entry, label );
+		g_object_get(
+				G_OBJECT( instance ),
+				MAIN_PROP_ITEM, &item,
+				NULL );
 
-		if( NA_IS_OBJECT_ACTION( item )){
-			setup_toolbar_label( instance, item, label );
+		if( item ){
+			label = gtk_entry_get_text( entry );
+			na_object_set_label( item, label );
+			check_for_label( instance, entry, label );
+
+			if( NA_IS_OBJECT_ACTION( item )){
+				setup_toolbar_label( instance, item, label );
+			}
+
+			g_signal_emit_by_name( G_OBJECT( instance ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, item, MAIN_DATA_LABEL );
 		}
-
-		g_signal_emit_by_name( G_OBJECT( instance ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, item, TRUE );
 	}
 }
 
@@ -682,13 +644,12 @@ on_target_toolbar_toggled( GtkToggleButton *button, NactIActionTab *instance )
 	gboolean editable;
 
 	if( !st_on_selection_change ){
-
 		g_debug( "%s: button=%p, instance=%p", thisfn, ( void * ) button, ( void * ) instance );
 
 		g_object_get(
 				G_OBJECT( instance ),
-				TAB_UPDATABLE_PROP_SELECTED_ITEM, &item,
-				TAB_UPDATABLE_PROP_EDITABLE, &editable,
+				MAIN_PROP_ITEM, &item,
+				MAIN_PROP_EDITABLE, &editable,
 				NULL );
 
 		g_debug( "%s: item=%p (%s), editable=%s",
@@ -700,7 +661,7 @@ on_target_toolbar_toggled( GtkToggleButton *button, NactIActionTab *instance )
 
 			if( editable ){
 				na_object_set_target_toolbar( item, is_target );
-				g_signal_emit_by_name( G_OBJECT( instance ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, item, FALSE );
+				g_signal_emit_by_name( G_OBJECT( instance ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, item, 0 );
 				toolbar_same_label_set_sensitive( instance, NA_OBJECT_ITEM( item ));
 				toolbar_label_set_sensitive( instance, NA_OBJECT_ITEM( item ));
 
@@ -728,8 +689,8 @@ on_toolbar_same_label_toggled( GtkToggleButton *button, NactIActionTab *instance
 
 		g_object_get(
 				G_OBJECT( instance ),
-				TAB_UPDATABLE_PROP_SELECTED_ITEM, &item,
-				TAB_UPDATABLE_PROP_EDITABLE, &editable,
+				MAIN_PROP_ITEM, &item,
+				MAIN_PROP_EDITABLE, &editable,
 				NULL );
 
 		g_debug( "%s: item=%p (%s), editable=%s",
@@ -749,7 +710,7 @@ on_toolbar_same_label_toggled( GtkToggleButton *button, NactIActionTab *instance
 					g_free( label );
 				}
 
-				g_signal_emit_by_name( G_OBJECT( instance ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, item, FALSE );
+				g_signal_emit_by_name( G_OBJECT( instance ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, item, 0 );
 				toolbar_same_label_set_sensitive( instance, NA_OBJECT_ITEM( item ));
 				toolbar_label_set_sensitive( instance, NA_OBJECT_ITEM( item ));
 
@@ -794,19 +755,24 @@ setup_toolbar_label( NactIActionTab *instance, NAObjectItem *item, const gchar *
 static void
 on_toolbar_label_changed( GtkEntry *entry, NactIActionTab *instance )
 {
+	static const gchar *thisfn = "nact_iaction_tab_on_toolbar_label_changed";
 	NAObjectItem *item;
 	const gchar *label;
 
-	g_object_get(
-			G_OBJECT( instance ),
-			TAB_UPDATABLE_PROP_SELECTED_ITEM, &item,
-			NULL );
+	if( !st_on_selection_change ){
+		g_debug( "%s: entry=%p, instance=%p", thisfn, ( void * ) entry, ( void * ) instance );
 
-	if( item && NA_IS_OBJECT_ACTION( item )){
-		label = gtk_entry_get_text( entry );
-		na_object_set_toolbar_label( NA_OBJECT_ACTION( item ), label );
+		g_object_get(
+				G_OBJECT( instance ),
+				MAIN_PROP_ITEM, &item,
+				NULL );
 
-		g_signal_emit_by_name( G_OBJECT( instance ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, item, FALSE );
+		if( item && NA_IS_OBJECT_ACTION( item )){
+			label = gtk_entry_get_text( entry );
+			na_object_set_toolbar_label( NA_OBJECT_ACTION( item ), label );
+
+			g_signal_emit_by_name( G_OBJECT( instance ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, item, 0 );
+		}
 	}
 }
 
@@ -826,90 +792,52 @@ toolbar_label_set_sensitive( NactIActionTab *instance, NAObjectItem *item )
 static void
 on_tooltip_changed( GtkEntry *entry, NactIActionTab *instance )
 {
+	static const gchar *thisfn = "nact_iaction_tab_on_tooltip_changed";
 	NAObjectItem *item;
 
-	g_object_get(
-			G_OBJECT( instance ),
-			TAB_UPDATABLE_PROP_SELECTED_ITEM, &item,
-			NULL );
+	if( !st_on_selection_change ){
+		g_debug( "%s: entry=%p, instance=%p", thisfn, ( void * ) entry, ( void * ) instance );
 
-	if( item ){
-		na_object_set_tooltip( item, gtk_entry_get_text( entry ));
-		g_signal_emit_by_name( G_OBJECT( instance ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, item, FALSE );
-	}
-}
+		g_object_get(
+				G_OBJECT( instance ),
+				MAIN_PROP_ITEM, &item,
+				NULL );
 
-static GtkTreeModel *
-create_stock_icon_model( void )
-{
-	GtkStockItem stock_item;
-	gchar* label;
-	GtkListStore *model;
-	GtkTreeIter row;
-	GSList *stock_list, *iter;
-	GtkIconTheme *icon_theme;
-	GtkIconInfo *icon_info;
-
-	model = gtk_list_store_new( ICON_N_COLUMN, G_TYPE_STRING, G_TYPE_STRING );
-
-	gtk_list_store_append( model, &row );
-	/* i18n notes: when no icon is selected in the drop-down list */
-	gtk_list_store_set( model, &row, ICON_STOCK_COLUMN, "", ICON_LABEL_COLUMN, _( "None" ), -1 );
-
-	stock_list = gtk_stock_list_ids();
-	icon_theme = gtk_icon_theme_get_default();
-	stock_list = g_slist_sort( stock_list, ( GCompareFunc ) sort_stock_ids_by_label );
-
-	for( iter = stock_list ; iter ; iter = iter->next ){
-		icon_info = gtk_icon_theme_lookup_icon( icon_theme, ( gchar * ) iter->data, GTK_ICON_SIZE_MENU, GTK_ICON_LOOKUP_GENERIC_FALLBACK );
-		if( icon_info ){
-			if( gtk_stock_lookup(( gchar * ) iter->data, &stock_item )){
-				gtk_list_store_append( model, &row );
-				label = strip_underscore( stock_item.label );
-				gtk_list_store_set( model, &row, ICON_STOCK_COLUMN, ( gchar * ) iter->data, ICON_LABEL_COLUMN, label, -1 );
-				g_free( label );
-			}
-			gtk_icon_info_free( icon_info );
+		if( item ){
+			na_object_set_tooltip( item, gtk_entry_get_text( entry ));
+			g_signal_emit_by_name( G_OBJECT( instance ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, item, 0 );
 		}
 	}
-
-	g_slist_foreach( stock_list, ( GFunc ) g_free, NULL );
-	g_slist_free( stock_list );
-
-	return( GTK_TREE_MODEL( model ));
-}
-
-static void
-icon_combo_list_set_layout( GtkComboBox *combo )
-{
-	GtkCellRenderer *cell_renderer_pix;
-	GtkCellRenderer *cell_renderer_text;
-
-	gtk_cell_layout_clear( GTK_CELL_LAYOUT( combo ));
-
-	cell_renderer_pix = gtk_cell_renderer_pixbuf_new();
-	gtk_cell_layout_pack_start( GTK_CELL_LAYOUT( combo ), cell_renderer_pix, FALSE );
-	gtk_cell_layout_add_attribute( GTK_CELL_LAYOUT( combo ), cell_renderer_pix, "stock-id", ICON_STOCK_COLUMN );
-
-	cell_renderer_text = gtk_cell_renderer_text_new();
-	gtk_cell_layout_pack_start( GTK_CELL_LAYOUT( combo ), cell_renderer_text, TRUE );
-	gtk_cell_layout_add_attribute( GTK_CELL_LAYOUT( combo ), cell_renderer_text, "text", ICON_LABEL_COLUMN );
-
-	gtk_combo_box_set_active( GTK_COMBO_BOX( combo ), 0 );
 }
 
 static void
 on_icon_browse( GtkButton *button, NactIActionTab *instance )
 {
-	nact_gtk_utils_select_file_with_preview(
-			BASE_WINDOW( instance ),
-			_( "Choosing an icon" ),
-			IPREFS_ICONS_DIALOG,
-			gtk_bin_get_child( GTK_BIN( get_icon_combo_box( instance ))),
-			IPREFS_ICONS_PATH,
-			"",
-			G_CALLBACK( icon_preview_cb )
-	);
+	static const gchar *thisfn = "nact_iaction_tab_on_icon_browse";
+	NAObjectItem *item;
+	GtkWidget *icon_entry;
+	gchar *icon_name;
+	gchar *new_icon_name;
+
+	g_debug( "%s: button=%p, instance=%p", thisfn, ( void * ) button, ( void * ) instance );
+
+	g_object_get(
+			G_OBJECT( instance ),
+			MAIN_PROP_ITEM, &item,
+			NULL );
+
+	if( item ){
+		icon_name = na_object_get_icon( item );
+		new_icon_name = nact_icon_chooser_choose_icon( BASE_WINDOW( instance ), icon_name );
+
+		if( g_utf8_collate( icon_name, new_icon_name ) != 0 ){
+			icon_entry = base_window_get_widget( BASE_WINDOW( instance ), "ActionIconEntry" );
+			gtk_entry_set_text( GTK_ENTRY( icon_entry ), new_icon_name );
+		}
+
+		g_free( icon_name );
+		g_free( new_icon_name );
+	}
 }
 
 static void
@@ -918,7 +846,7 @@ on_icon_changed( GtkEntry *icon_entry, NactIActionTab *instance )
 	static const gchar *thisfn = "nact_iaction_tab_on_icon_changed";
 	GtkImage *image;
 	NAObjectItem *item;
-	const gchar *icon_name;
+	gchar *icon_name;
 
 	g_debug( "%s: entry=%p, instance=%p", thisfn, ( void * ) icon_entry, ( void * ) instance );
 
@@ -926,112 +854,24 @@ on_icon_changed( GtkEntry *icon_entry, NactIActionTab *instance )
 
 	g_object_get(
 			G_OBJECT( instance ),
-			TAB_UPDATABLE_PROP_SELECTED_ITEM, &item,
+			MAIN_PROP_ITEM, &item,
 			NULL );
 
 	if( item ){
-		icon_name = gtk_entry_get_text( icon_entry );
-		na_object_set_icon( item, icon_name );
-		g_signal_emit_by_name( G_OBJECT( instance ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, item, TRUE );
+		if( !st_on_selection_change ){
+			icon_name = g_strdup( gtk_entry_get_text( icon_entry ));
+			na_object_set_icon( item, icon_name );
+			g_signal_emit_by_name( G_OBJECT( instance ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, item, MAIN_DATA_ICON );
+
+		} else {
+			icon_name = na_object_get_icon( item );
+		}
 	}
 
 	/* icon_name may be null if there is no current item
 	 * in such a case, we blank the image
 	 */
 	image = GTK_IMAGE( base_window_get_widget( BASE_WINDOW( instance ), "ActionIconImage" ));
-	nact_gtk_utils_render( icon_name, image, GTK_ICON_SIZE_SMALL_TOOLBAR );
-}
-
-static void
-icon_preview_cb( GtkFileChooser *dialog, GtkWidget *preview )
-{
-	char *filename;
-	GdkPixbuf *pixbuf;
-	gboolean have_preview;
-
-	filename = gtk_file_chooser_get_preview_filename( dialog );
-	pixbuf = gdk_pixbuf_new_from_file_at_size( filename, 128, 128, NULL );
-	have_preview = ( pixbuf != NULL );
-	g_free( filename );
-
-	if( have_preview ){
-		gtk_image_set_from_pixbuf( GTK_IMAGE( preview ), pixbuf );
-		g_object_unref( pixbuf );
-	}
-
-	gtk_file_chooser_set_preview_widget_active( dialog, have_preview );
-}
-
-static gint
-sort_stock_ids_by_label( gconstpointer a, gconstpointer b )
-{
-	GtkStockItem stock_item_a;
-	GtkStockItem stock_item_b;
-	gchar *label_a, *label_b;
-	gboolean is_a, is_b;
-	int retv = 0;
-
-	is_a = gtk_stock_lookup(( gchar * ) a, &stock_item_a );
-	is_b = gtk_stock_lookup(( gchar * ) b, &stock_item_b );
-
-	if( is_a && !is_b ){
-		retv = 1;
-
-	} else if( !is_a && is_b ){
-		retv = -1;
-
-	} else if( !is_a && !is_b ){
-		retv = 0;
-
-	} else {
-		label_a = strip_underscore( stock_item_a.label );
-		label_b = strip_underscore( stock_item_b.label );
-		retv = na_core_utils_str_collate( label_a, label_b );
-		g_free( label_a );
-		g_free( label_b );
-	}
-
-	return( retv );
-}
-
-static gchar *
-strip_underscore( const gchar *text )
-{
-	/* Code from gtk-demo */
-	gchar *p, *q, *result;
-
-	result = g_strdup( text );
-	p = q = result;
-	while( *p ){
-		if( *p != '_' ){
-			*q = *p;
-			q++;
-		}
-		p++;
-	}
-	*q = '\0';
-
-	return( result );
-}
-
-static void
-release_icon_combobox( NactIActionTab *instance )
-{
-	GtkWidget *combo;
-	GtkTreeModel *model;
-
-	combo = get_icon_combo_box( instance );
-	model = gtk_combo_box_get_model( GTK_COMBO_BOX( combo ));
-	gtk_list_store_clear( GTK_LIST_STORE( model ));
-}
-
-static GtkWidget *
-get_icon_combo_box( NactIActionTab *instance )
-{
-	GtkWidget *icon_box, *icon_combo;
-
-	icon_box = base_window_get_widget( BASE_WINDOW( instance ), "ActionIconHBox" );
-	icon_combo = GTK_WIDGET( gtk_container_get_children( GTK_CONTAINER( icon_box ))->data );
-
-	return( icon_combo );
+	base_gtk_utils_render( icon_name, image, GTK_ICON_SIZE_SMALL_TOOLBAR );
+	g_free( icon_name );
 }
