@@ -43,30 +43,19 @@
 #include <core/na-tokens.h>
 
 #include "base-window.h"
-#include "base-iprefs.h"
 #include "nact-application.h"
 #include "nact-main-statusbar.h"
-#include "nact-gtk-utils.h"
-#include "nact-iprefs.h"
-#include "nact-iactions-list.h"
+#include "base-gtk-utils.h"
 #include "nact-main-tab.h"
 #include "nact-icommand-tab.h"
 #include "nact-ischemes-tab.h"
 
 /* private interface data
  */
-struct NactICommandTabInterfacePrivate {
+struct _NactICommandTabInterfacePrivate {
 	void *empty;						/* so that gcc -pedantic is happy */
 };
 
-/* the GConf key used to read/write size and position of auxiliary dialogs
- */
-#define IPREFS_LEGEND_DIALOG				"icommand-legend-dialog"
-#define IPREFS_COMMAND_CHOOSER				"icommand-command-chooser"
-#define IPREFS_FOLDER_URI					"icommand-folder-uri"
-#define IPREFS_WORKING_DIR_DIALOG			"icommand-working-dir-dialog"
-#define IPREFS_WORKING_DIR_URI				"icommand-working-dir-uri"
-
 /* a data set in the LegendDialog GObject
  */
 #define ICOMMAND_TAB_LEGEND_VISIBLE			"nact-icommand-tab-legend-dialog-visible"
@@ -81,8 +70,8 @@ static GType      register_type( void );
 static void       interface_base_init( NactICommandTabInterface *klass );
 static void       interface_base_finalize( NactICommandTabInterface *klass );
 
-static void       on_iactions_list_column_edited( NactICommandTab *instance, NAObject *object, gchar *text, gint column );
-static void       on_tab_updatable_selection_changed( NactICommandTab *instance, gint count_selected );
+static void       on_tree_view_content_changed( NactICommandTab *instance, NAObject *object, gpointer user_data );
+static void       on_main_selection_changed( NactICommandTab *instance, GList *selected_items, gpointer user_data );
 
 static GtkWidget *get_label_entry( NactICommandTab *instance );
 static GtkButton *get_legend_button( NactICommandTab *instance );
@@ -192,10 +181,6 @@ nact_icommand_tab_initial_load_toplevel( NactICommandTab *instance )
 	if( st_initialized && !st_finalized ){
 
 		g_debug( "%s: instance=%p", thisfn, ( void * ) instance );
-
-		nact_iprefs_migrate_key( BASE_WINDOW( instance ), "iconditions-legend-dialog", IPREFS_LEGEND_DIALOG );
-		nact_iprefs_migrate_key( BASE_WINDOW( instance ), "iconditions-command-chooser", IPREFS_COMMAND_CHOOSER );
-		nact_iprefs_migrate_key( BASE_WINDOW( instance ), "iconditions-folder-uri", IPREFS_FOLDER_URI );
 	}
 }
 
@@ -276,17 +261,11 @@ nact_icommand_tab_runtime_init_toplevel( NactICommandTab *instance )
 				"clicked",
 				G_CALLBACK( on_wdir_browse ));
 
-		base_window_signal_connect(
-				BASE_WINDOW( instance ),
-				G_OBJECT( instance ),
-				MAIN_WINDOW_SIGNAL_SELECTION_CHANGED,
-				G_CALLBACK( on_tab_updatable_selection_changed ));
+		base_window_signal_connect( BASE_WINDOW( instance ),
+				G_OBJECT( instance ), MAIN_SIGNAL_SELECTION_CHANGED, G_CALLBACK( on_main_selection_changed ));
 
-		base_window_signal_connect(
-				BASE_WINDOW( instance ),
-				G_OBJECT( instance ),
-				IACTIONS_LIST_SIGNAL_COLUMN_EDITED,
-				G_CALLBACK( on_iactions_list_column_edited ));
+		base_window_signal_connect( BASE_WINDOW( instance ),
+				G_OBJECT( instance ), MAIN_SIGNAL_ITEM_UPDATED, G_CALLBACK( on_tree_view_content_changed ));
 
 		/* allocate a static fake NATokens object which will be user to build
 		 * the example label - this object will be unreffed on dispose
@@ -336,9 +315,10 @@ nact_icommand_tab_dispose( NactICommandTab *instance )
 }
 
 static void
-on_iactions_list_column_edited( NactICommandTab *instance, NAObject *object, gchar *text, gint column )
+on_tree_view_content_changed( NactICommandTab *instance, NAObject *object, gpointer user_data )
 {
 	GtkWidget *label_widget;
+	gchar *label;
 
 	g_return_if_fail( NACT_IS_ICOMMAND_TAB( instance ));
 
@@ -346,15 +326,17 @@ on_iactions_list_column_edited( NactICommandTab *instance, NAObject *object, gch
 
 		if( NA_IS_OBJECT_PROFILE( object )){
 			label_widget = get_label_entry( instance );
-			gtk_entry_set_text( GTK_ENTRY( label_widget ), text );
+			label = na_object_get_label( object );
+			gtk_entry_set_text( GTK_ENTRY( label_widget ), label );
+			g_free( label );
 		}
 	}
 }
 
 static void
-on_tab_updatable_selection_changed( NactICommandTab *instance, gint count_selected )
+on_main_selection_changed( NactICommandTab *instance, GList *selected_items, gpointer user_data )
 {
-	static const gchar *thisfn = "nact_icommand_tab_on_tab_updatable_selection_changed";
+	static const gchar *thisfn = "nact_icommand_tab_on_main_selection_changed";
 	NAObjectProfile *profile;
 	gboolean editable;
 	gboolean enable_tab;
@@ -366,13 +348,13 @@ on_tab_updatable_selection_changed( NactICommandTab *instance, gint count_select
 	g_return_if_fail( NACT_IS_ICOMMAND_TAB( instance ));
 
 	if( st_initialized && !st_finalized ){
-
-		g_debug( "%s: instance=%p, count_selected=%d", thisfn, ( void * ) instance, count_selected );
+		g_debug( "%s: instance=%p, selected_items=%p (count=%d)",
+				thisfn, ( void * ) instance, ( void * ) selected_items, g_list_length( selected_items ));
 
 		g_object_get(
 				G_OBJECT( instance ),
-				TAB_UPDATABLE_PROP_SELECTED_PROFILE, &profile,
-				TAB_UPDATABLE_PROP_EDITABLE, &editable,
+				MAIN_PROP_PROFILE, &profile,
+				MAIN_PROP_EDITABLE, &editable,
 				NULL );
 
 		enable_tab = ( profile != NULL );
@@ -386,7 +368,7 @@ on_tab_updatable_selection_changed( NactICommandTab *instance, gint count_select
 		gtk_entry_set_text( GTK_ENTRY( label_entry ), label );
 		g_free( label );
 		gtk_widget_set_sensitive( label_entry, profile != NULL );
-		nact_gtk_utils_set_editable( G_OBJECT( label_entry ), editable );
+		base_gtk_utils_set_editable( G_OBJECT( label_entry ), editable );
 
 		path_entry = get_path_entry( instance );
 		path = profile ? na_object_get_path( profile ) : g_strdup( "" );
@@ -394,11 +376,11 @@ on_tab_updatable_selection_changed( NactICommandTab *instance, gint count_select
 		gtk_entry_set_text( GTK_ENTRY( path_entry ), path );
 		g_free( path );
 		gtk_widget_set_sensitive( path_entry, profile != NULL );
-		nact_gtk_utils_set_editable( G_OBJECT( path_entry ), editable );
+		base_gtk_utils_set_editable( G_OBJECT( path_entry ), editable );
 
 		path_button = get_path_button( instance );
 		gtk_widget_set_sensitive( GTK_WIDGET( path_button ), profile != NULL );
-		nact_gtk_utils_set_editable( G_OBJECT( path_button ), editable );
+		base_gtk_utils_set_editable( G_OBJECT( path_button ), editable );
 
 		parameters_entry = get_parameters_entry( instance );
 		parameters = profile ? na_object_get_parameters( profile ) : g_strdup( "" );
@@ -406,7 +388,7 @@ on_tab_updatable_selection_changed( NactICommandTab *instance, gint count_select
 		gtk_entry_set_text( GTK_ENTRY( parameters_entry ), parameters );
 		g_free( parameters );
 		gtk_widget_set_sensitive( parameters_entry, profile != NULL );
-		nact_gtk_utils_set_editable( G_OBJECT( parameters_entry ), editable );
+		base_gtk_utils_set_editable( G_OBJECT( parameters_entry ), editable );
 
 		legend_button = get_legend_button( instance );
 		gtk_widget_set_sensitive( GTK_WIDGET( legend_button ), profile != NULL );
@@ -419,11 +401,11 @@ on_tab_updatable_selection_changed( NactICommandTab *instance, gint count_select
 		gtk_entry_set_text( GTK_ENTRY( wdir_entry ), wdir );
 		g_free( wdir );
 		gtk_widget_set_sensitive( wdir_entry, profile != NULL );
-		nact_gtk_utils_set_editable( G_OBJECT( wdir_entry ), editable );
+		base_gtk_utils_set_editable( G_OBJECT( wdir_entry ), editable );
 
 		wdir_button = GTK_BUTTON( base_window_get_widget( BASE_WINDOW( instance ), "CommandWorkingDirectoryButton" ));
 		gtk_widget_set_sensitive( GTK_WIDGET( wdir_button ), profile != NULL );
-		nact_gtk_utils_set_editable( G_OBJECT( wdir_button ), editable );
+		base_gtk_utils_set_editable( G_OBJECT( wdir_button ), editable );
 
 		st_on_selection_change = FALSE;
 	}
@@ -444,7 +426,7 @@ get_legend_button( NactICommandTab *instance )
 static GtkWindow *
 get_legend_dialog( NactICommandTab *instance )
 {
-	return( base_window_get_named_toplevel( BASE_WINDOW( instance ), "LegendDialog" ));
+	return( base_window_get_gtk_toplevel_by_name( BASE_WINDOW( instance ), "LegendDialog" ));
 }
 
 static GtkWidget *
@@ -478,7 +460,7 @@ legend_dialog_hide( NactICommandTab *instance )
 
 	if( is_visible ){
 		g_return_if_fail( GTK_IS_WINDOW( legend_dialog ));
-		base_iprefs_save_named_window_position( BASE_WINDOW( instance ), legend_dialog, IPREFS_LEGEND_DIALOG );
+		base_gtk_utils_save_window_position( BASE_WINDOW( instance ), NA_IPREFS_COMMAND_LEGEND_WSP );
 		gtk_widget_hide( GTK_WIDGET( legend_dialog ));
 
 		/* set the legend button state consistent for when the dialog is
@@ -500,10 +482,10 @@ legend_dialog_show( NactICommandTab *instance )
 	legend_dialog = get_legend_dialog( instance );
 	gtk_window_set_deletable( legend_dialog, FALSE );
 
-	toplevel = base_window_get_toplevel( BASE_WINDOW( instance ));
+	toplevel = base_window_get_gtk_toplevel( BASE_WINDOW( instance ));
 	gtk_window_set_transient_for( GTK_WINDOW( legend_dialog ), toplevel );
 
-	base_iprefs_position_named_window( BASE_WINDOW( instance ), legend_dialog, IPREFS_LEGEND_DIALOG );
+	base_gtk_utils_restore_window_position( BASE_WINDOW( instance ), NA_IPREFS_COMMAND_LEGEND_WSP );
 	gtk_widget_show( GTK_WIDGET( legend_dialog ));
 
 	g_object_set_data( G_OBJECT( legend_dialog ), ICOMMAND_TAB_LEGEND_VISIBLE, GINT_TO_POINTER( TRUE ));
@@ -518,13 +500,13 @@ on_label_changed( GtkEntry *entry, NactICommandTab *instance )
 	if( !st_on_selection_change ){
 		g_object_get(
 				G_OBJECT( instance ),
-				TAB_UPDATABLE_PROP_SELECTED_PROFILE, &profile,
+				MAIN_PROP_PROFILE, &profile,
 				NULL );
 
 		if( profile ){
 			label = gtk_entry_get_text( entry );
 			na_object_set_label( profile, label );
-			g_signal_emit_by_name( G_OBJECT( instance ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, profile, TRUE );
+			g_signal_emit_by_name( G_OBJECT( instance ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, profile, MAIN_DATA_LABEL );
 		}
 	}
 }
@@ -556,12 +538,12 @@ on_parameters_changed( GtkEntry *entry, NactICommandTab *instance )
 	if( !st_on_selection_change ){
 		g_object_get(
 				G_OBJECT( instance ),
-				TAB_UPDATABLE_PROP_SELECTED_PROFILE, &profile,
+				MAIN_PROP_PROFILE, &profile,
 				NULL );
 
 		if( profile ){
 			na_object_set_parameters( profile, gtk_entry_get_text( entry ));
-			g_signal_emit_by_name( G_OBJECT( instance ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, profile, FALSE );
+			g_signal_emit_by_name( G_OBJECT( instance ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, profile, 0 );
 			update_example_label( instance, profile );
 		}
 	}
@@ -570,10 +552,10 @@ on_parameters_changed( GtkEntry *entry, NactICommandTab *instance )
 static void
 on_path_browse( GtkButton *button, NactICommandTab *instance )
 {
-	nact_gtk_utils_select_file(
+	base_gtk_utils_select_file(
 			BASE_WINDOW( instance ),
-			_( "Choosing a command" ), IPREFS_COMMAND_CHOOSER,
-			get_path_entry( instance ), IPREFS_FOLDER_URI, "file:///bin" );
+			_( "Choosing a command" ), NA_IPREFS_COMMAND_CHOOSER_WSP,
+			get_path_entry( instance ), NA_IPREFS_COMMAND_CHOOSER_URI );
 }
 
 static void
@@ -584,12 +566,12 @@ on_path_changed( GtkEntry *entry, NactICommandTab *instance )
 	if( !st_on_selection_change ){
 		g_object_get(
 				G_OBJECT( instance ),
-				TAB_UPDATABLE_PROP_SELECTED_PROFILE, &profile,
+				MAIN_PROP_PROFILE, &profile,
 				NULL );
 
 		if( profile ){
 			na_object_set_path( profile, gtk_entry_get_text( entry ));
-			g_signal_emit_by_name( G_OBJECT( instance ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, profile, FALSE );
+			g_signal_emit_by_name( G_OBJECT( instance ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, profile, 0 );
 			update_example_label( instance, profile );
 		}
 	}
@@ -600,23 +582,17 @@ on_wdir_browse( GtkButton *button, NactICommandTab *instance )
 {
 	GtkWidget *wdir_entry;
 	NAObjectProfile *profile;
-	gchar *default_value;
 
 	g_object_get(
 			G_OBJECT( instance ),
-			TAB_UPDATABLE_PROP_SELECTED_PROFILE, &profile,
+			MAIN_PROP_PROFILE, &profile,
 			NULL );
 
 	if( profile ){
-		default_value = na_factory_object_get_default( NA_IFACTORY_OBJECT( profile ), NAFO_DATA_WORKING_DIR );
 		wdir_entry = base_window_get_widget( BASE_WINDOW( instance ), "WorkingDirectoryEntry" );
-
-		nact_gtk_utils_select_dir(
-				BASE_WINDOW( instance ),
-				_( "Choosing a working directory" ), IPREFS_WORKING_DIR_DIALOG,
-				wdir_entry, IPREFS_WORKING_DIR_URI, default_value );
-
-		g_free( default_value );
+		base_gtk_utils_select_dir(
+				BASE_WINDOW( instance ), _( "Choosing a working directory" ),
+				NA_IPREFS_WORKING_DIR_WSP, wdir_entry, NA_IPREFS_WORKING_DIR_URI );
 	}
 }
 
@@ -628,12 +604,12 @@ on_wdir_changed( GtkEntry *entry, NactICommandTab *instance )
 	if( !st_on_selection_change ){
 		g_object_get(
 				G_OBJECT( instance ),
-				TAB_UPDATABLE_PROP_SELECTED_PROFILE, &profile,
+				MAIN_PROP_PROFILE, &profile,
 				NULL );
 
 		if( profile ){
 			na_object_set_working_dir( profile, gtk_entry_get_text( entry ));
-			g_signal_emit_by_name( G_OBJECT( instance ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, profile, FALSE );
+			g_signal_emit_by_name( G_OBJECT( instance ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, profile, 0 );
 		}
 	}
 }
